==> gsf-0.2.0.tar.bz2: gsf-0.2.0/src/dvbstatus.h <==
/*
 *      dvbstatus.h
 *      
 *      Copyright 2009 - 2010 Alex <alex@linuxonly.ru>
 *      
 *      This program is free software: you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __DVBSTATUS_H__
#define __DVBSTATUS_H__

#include <glib.h>
#include "mainwindow.h"
#include "dbstorage.h"
#include "satscanwindow.h"

gboolean dvb_demux_close(struct _frontend *frontend, struct _demuxer *demuxer, struct _service *svc);
gboolean dvb_demux_open(struct _frontend *frontend, struct _demuxer *demuxer, struct _service *svc);
gboolean dvb_tune(struct _frontend *frontend, struct _service *svc);
gboolean dvb_parameters(struct _frontend *frontend, struct _service *svc);
gboolean dvb_status(struct _frontend *frontend, gint (*event_cb)(gint status, uint32_t freq, uint32_t sr, gint fec));
gboolean dvb_frontend_opened(gint fd);
gint dvb_open(struct _frontend *frontend);
gboolean dvb_close(struct _frontend *frontend);

gboolean dvb_satscan_init(struct _frontend *frontend, struct _transponders *transponders);
void dvb_satscan_tune_callback(struct _transponder *transponder, struct _frontend *frontend);

#endif /* __DVBSTATUS_H__ */

==> gsf-0.2.1.tar.bz2: gsf-0.2.1/src/dvbstatus.h <==
/*
 *      dvbstatus.h
 *      
 *      Copyright 2009 - 2010 Alex <alex@linuxonly.ru>
 *      
 *      This program is free software: you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __DVBSTATUS_H__
#define __DVBSTATUS_H__

#include <glib.h>
#include "mainwindow.h"
#include "dbstorage.h"
#include "satscanwindow.h"

gboolean dvb_demux_close(struct _frontend *frontend, struct _demuxer *demuxer, struct _service *svc);
gboolean dvb_demux_open(struct _frontend *frontend, struct _demuxer *demuxer, struct _service *svc);
gboolean dvb_tune(struct _frontend *frontend, struct _service *svc);
gboolean dvb_parameters(struct _frontend *frontend, struct _service *svc);
gboolean dvb_status(struct _frontend *frontend, struct _service *svc, gint (*event_cb)(gint status, uint32_t freq, uint32_t sr, gint fec));
gboolean dvb_frontend_opened(gint fd);
gint dvb_open(struct _frontend *frontend);
gboolean dvb_close(struct _frontend *frontend);

gboolean dvb_satscan_init(struct _frontend *frontend, struct _transponders *transponders);
void dvb_satscan_tune_callback(struct _transponder *transponder, struct _frontend *frontend);

#endif /* __DVBSTATUS_H__ */
